@@ -2,29 +2,31 @@
 
 from getpass import getuser
 from ipaddress import ip_address, ip_network
-from random import choice
+from jinja2 import Environment, FileSystemLoader
+from jinja2 import StrictUndefined as strictundefined
+from jinja2.runtime import Undefined as defaultundefined
+from jinja2.exceptions import TemplateSyntaxError, TemplateError, TemplateNotFound
+from kvirt import common
+from kvirt.common import error, pprint, warning, container_mode, ssh, scp, NoAliasDumper
+from kvirt.common import PlanLoader
+from kvirt import defaults as kdefaults
 from kvirt.cluster import hypershift
 from kvirt.cluster import k3s
 from kvirt.cluster import kubeadm
 from kvirt.cluster import microshift
 from kvirt.cluster import openshift
 from kvirt.cluster import rke2
-from kvirt import common
-from kvirt.common import error, pprint, warning, container_mode, ssh, scp, NoAliasDumper
-from kvirt import defaults as kdefaults
 from kvirt.jinjafilters import jinjafilters
 import os
-from shutil import copytree, rmtree, which, copy2
-import yaml
-from jinja2 import Environment, FileSystemLoader
-from jinja2 import StrictUndefined as strictundefined
-from jinja2.runtime import Undefined as defaultundefined
-from jinja2.exceptions import TemplateSyntaxError, TemplateError, TemplateNotFound
+from random import choice
 import re
-import sys
+import stat
 from subprocess import call
+import sys
+from shutil import copytree, rmtree, which, copy2
 from tempfile import TemporaryDirectory
 from time import sleep
+import yaml
 
 
 def other_client(profile, clients):
@@ -191,7 +193,6 @@ class Kbaseconfig:
         defaults['initrd'] = default.get('initrd', kdefaults.INITRD)
         defaults['cmdline'] = default.get('cmdline', kdefaults.CMDLINE)
         defaults['placement'] = default.get('placement', kdefaults.PLACEMENT)
-        defaults['yamlinventory'] = default.get('yamlinventory', kdefaults.YAMLINVENTORY)
         defaults['cpuhotplug'] = bool(default.get('cpuhotplug', kdefaults.CPUHOTPLUG))
         defaults['memoryhotplug'] = bool(default.get('memoryhotplug', kdefaults.MEMORYHOTPLUG))
         defaults['virttype'] = default.get('virttype', kdefaults.VIRTTYPE)
@@ -426,7 +427,6 @@ class Kbaseconfig:
         self.initrd = options.get('initrd')
         self.cmdline = options.get('cmdline')
         self.placement = options.get('placement')
-        self.yamlinventory = options.get('yamlinventory')
         self.cpuhotplug = options.get('cpuhotplug')
         self.memoryhotplug = options.get('memoryhotplug')
         self.virttype = options.get('virttype')
@@ -724,7 +724,7 @@ class Kbaseconfig:
                 return {'product': product, 'parameters': parameters}
 
     def process_inputfile(self, plan, inputfile, overrides={}, onfly=None, full=False, ignore=False,
-                          download_mode=False, extra_funcs=[]):
+                          download_mode=False, extra_funcs=[], split=False):
         default_dir = '/workdir' if container_mode() else '.'
         basedir = os.path.dirname(inputfile) if os.path.dirname(inputfile) != '' else default_dir
         basefile = None
@@ -782,6 +782,21 @@ class Kbaseconfig:
                             overrides[baseparameter] = baseparameters[baseparameter]
             for parameter in parameters:
                 if parameter in overrides:
+                    parameter_type = type(parameters[parameter])
+                    override_type = type(overrides[parameter])
+                    if parameter_type == str and override_type == type(None):
+                        continue
+                    if parameters[parameter] is not None and override_type != parameter_type:
+                        msg = f"Parameter {parameter} doesn't have type {parameter_type}"
+                        if parameter_type == str and override_type in [int, float]:
+                            try:
+                                float(overrides[parameter])
+                            except:
+                                error(msg)
+                                sys.exit(1)
+                        else:
+                            error(msg)
+                            sys.exit(1)
                     continue
                 currentparameter = parameters[parameter]
                 if isinstance(currentparameter, bool) and download_mode:
@@ -805,7 +820,10 @@ class Kbaseconfig:
                             break
                 return entries
             try:
-                entries = yaml.safe_load(entries)
+                if split:
+                    entries = yaml.load(entries, Loader=PlanLoader)
+                else:
+                    entries = yaml.safe_load(entries)
             except Exception as e:
                 error(f"Couldn't load file. Hit {e}")
                 sys.exit(1)
@@ -1295,6 +1313,7 @@ class Kbaseconfig:
                 f.write(myfile01data)
 
     def create_workflow(self, workflow, overrides={}, outputdir=None, run=True):
+        cwd = os.getcwd()
         target = overrides.get('target')
         if target is not None:
             if isinstance(target, str):
@@ -1335,80 +1354,126 @@ class Kbaseconfig:
                 msg = "No scripts provided"
                 error(msg)
                 return {'result': 'failure', 'reason': msg}
+        default_destdir = outputdir or '/root'
+        directoryfiles = []
+        treatedfiles = []
+        directories = []
+        for entry in files:
+            if not isinstance(entry, dict):
+                entry = {'origin': entry}
+            origin = os.path.expanduser(entry.get('origin'))
+            destdir = os.path.dirname(entry.get('path')) if 'path' in entry else default_destdir
+            content = entry.get('content')
+            render = entry.get('render', True)
+            if isinstance(render, str):
+                render = render.lower() == 'true'
+            if origin in directories:
+                continue
+            elif not os.path.exists(origin):
+                msg = f"Origin file {origin} not found"
+                error(msg)
+                return {'result': 'failure', 'reason': msg}
+            elif os.path.isdir(origin):
+                origin = entry.get('origin')
+                if not os.path.exists(f"{destdir}/{origin}"):
+                    os.makedirs(f"{destdir}/{origin}")
+                    directories.append(origin)
+                for _fic in os.listdir(origin):
+                    directoryfiles.append(f'{origin}/{_fic}')
+                continue
+            filename = os.path.basename(origin)
+            if not render:
+                content = open(origin, 'r').read()
+            rendered = content or self.process_inputfile(workflow, origin, overrides=overrides)
+            destfile = f"{destdir}/{filename}"
+            if 'path' in entry:
+                destfile = entry['path']
+            if not os.path.exists(os.path.dirname(destfile)):
+                pprint(f"Creating directory {os.path.dirname(destfile)}")
+                os.makedirs(os.path.dirname(destfile))
+            with open(destfile, 'w') as f:
+                pprint(f"Copying rendered file {filename} to {destfile}")
+                f.write(rendered)
+                os.chmod(destfile, stat.S_IMODE(os.stat(origin).st_mode))
+            treatedfiles.append(origin)
+        for entry in directoryfiles:
+            if entry in treatedfiles:
+                continue
+            entrydir = os.path.dirname(entry)
+            entryname = os.path.basename(entry)
+            rendered = self.process_inputfile(workflow, entry, overrides=overrides)
+            destfile = f"{destdir}/{entrydir}/{entryname}"
+            with open(destfile, 'w') as f:
+                f.write(rendered)
+                os.chmod(destfile, stat.S_IMODE(os.stat(entry).st_mode))
         finalscripts = []
-        with TemporaryDirectory() as tmpdir:
-            destdir = outputdir or tmpdir
-            directoryfiles = []
-            directories = []
-            for index, entry in enumerate(scripts + files):
-                if isinstance(entry, dict):
-                    origin = os.path.expanduser(entry.get('origin') or entry.get('path'))
-                    content = entry.get('content')
-                else:
-                    origin = os.path.expanduser(entry)
-                    content = None
-                if origin in directories:
-                    continue
-                elif not os.path.exists(origin):
-                    msg = f"Origin file {origin} not found"
+        tmpdir = None
+        if outputdir is None:
+            tmpdir = TemporaryDirectory()
+        destdir = outputdir or tmpdir.name
+        for entry in scripts:
+            origin = os.path.expanduser(entry)
+            if not os.path.exists(origin):
+                msg = f"Origin file {origin} not found"
+                error(msg)
+                return {'result': 'failure', 'reason': msg}
+            elif os.path.isdir(origin):
+                origin = entry.get('origin')
+                if not os.path.exists(f"{destdir}/{origin}"):
+                    os.makedirs(f"{destdir}/{origin}")
+                    directories.append(origin)
+                for _fic in os.listdir(origin):
+                    directoryfiles.append(f'{origin}/{_fic}')
+                continue
+            scriptname = os.path.basename(origin)
+            rendered = content or self.process_inputfile(workflow, origin, overrides=overrides)
+            destfile = f"{destdir}/{scriptname}"
+            if 'path' in destfile:
+                destfile = entry.get('path')
+            if not os.path.exists(os.path.dirname(destfile)):
+                pprint(f"Creating directory {os.path.dirname(destfile)}")
+                os.makedirs(os.path.exists(os.path.dirname(destfile)))
+            with open(destfile, 'w') as f:
+                f.write(rendered)
+            finalscripts.append(scriptname)
+        if cmds:
+            cmdscontent = '\n'.join(cmds)
+            destfile = f"{destdir}/cmds.sh"
+            with open(destfile, 'w') as f:
+                f.write(cmdscontent)
+            finalscripts.append('cmds.sh')
+        if not run:
+            pprint("Not running as dry mode was requested")
+            return {'result': 'success'}
+        if target is not None:
+            remotedir = f"/tmp/{os.path.basename(tmpdir)}"
+            scpcmd = scp(hostname, ip=ip, user=user, source=tmpdir, destination=remotedir, download=False,
+                         insecure=True, tunnel=tunnel, tunnelhost=tunnelhost, tunnelport=tunnelport,
+                         tunneluser=tunneluser, vmport=vmport)
+            os.system(scpcmd)
+            cmd = [f"cd {remotedir}"]
+            for script in finalscripts:
+                cmd.append(f'bash {script}' if script.endswith('.sh') else f'./{script}')
+            cmd.append(f"rm -rf {remotedir}")
+            cmd = ';'.join(cmd)
+            pprint(f"Running script {script} on {hostname}")
+            sshcommand = ssh(hostname, ip=ip, user=user, cmd=cmd, tunnel=tunnel, tunnelhost=tunnelhost,
+                             tunnelport=tunnelport, tunneluser=tunneluser, vmport=vmport)
+            os.system(sshcommand)
+        else:
+            os.chdir(destdir)
+            for script in finalscripts:
+                os.chmod(script, 0o700)
+                pprint(f"Running script {script} locally")
+                command = f'bash {script}' if script.endswith('.sh') else f'./{script}'
+                result = call(command, shell=True)
+                if result != 0:
+                    msg = f"Failure in script {script}"
                     error(msg)
                     return {'result': 'failure', 'reason': msg}
-                elif os.path.isdir(origin):
-                    origindir = entry if not isinstance(entry, dict) else entry.get('origin') or entry.get('path')
-                    if not os.path.exists(f"{destdir}/{origindir}"):
-                        os.makedirs(f"{destdir}/{origindir}")
-                        directories.append(origin)
-                        for _fic in os.listdir(origindir):
-                            directoryfiles.append(f'{origindir}/{_fic}')
-                    continue
-                path = os.path.basename(origin)
-                rendered = content or self.process_inputfile(workflow, origin, overrides=overrides)
-                destfile = f"{destdir}/{path}"
-                with open(destfile, 'w') as f:
-                    f.write(rendered)
-                if index < len(scripts):
-                    finalscripts.append(path)
-            for entry in directoryfiles:
-                path = os.path.basename(entry)
-                rendered = self.process_inputfile(workflow, entry, overrides=overrides)
-                destfile = f"{destdir}/{path}"
-                with open(destfile, 'w') as f:
-                    f.write(rendered)
-            if cmds:
-                cmdscontent = '\n'.join(cmds)
-                destfile = f"{destdir}/cmds.sh"
-                with open(destfile, 'w') as f:
-                    f.write(cmdscontent)
-                finalscripts.append('cmds.sh')
-            if not run:
-                pprint("Not running as dry mode was requested")
-                return {'result': 'success'}
-            if target is not None:
-                remotedir = f"/tmp/{os.path.basename(tmpdir)}"
-                scpcmd = scp(hostname, ip=ip, user=user, source=tmpdir, destination=remotedir, download=False,
-                             insecure=True, tunnel=tunnel, tunnelhost=tunnelhost, tunnelport=tunnelport,
-                             tunneluser=tunneluser, vmport=vmport)
-                os.system(scpcmd)
-                cmd = [f"cd {remotedir}"]
-                for script in finalscripts:
-                    cmd.append(f'bash {script}' if script.endswith('.sh') else f'./{script}')
-                cmd.append(f"rm -rf {remotedir}")
-                cmd = ';'.join(cmd)
-                pprint(f"Running script {script} on {hostname}")
-                sshcommand = ssh(hostname, ip=ip, user=user, cmd=cmd, tunnel=tunnel, tunnelhost=tunnelhost,
-                                 tunnelport=tunnelport, tunneluser=tunneluser, vmport=vmport)
-                os.system(sshcommand)
-            else:
-                os.chdir(destdir)
-                for script in finalscripts:
-                    os.chmod(script, 0o700)
-                    pprint(f"Running script {script} locally")
-                    command = f'bash {script}' if script.endswith('.sh') else f'./{script}'
-                    result = call(command, shell=True)
-                    if result != 0:
-                        msg = f"Failure in script {script}"
-                        error(msg)
-                        return {'result': 'failure', 'reason': msg}
+        if tmpdir is not None:
+            tmpdir.cleanup()
+        os.chdir(cwd)
         return {'result': 'success'}
 
     def info_keyword(self, keyword):
@@ -1525,7 +1590,7 @@ class Kbaseconfig:
             warning("ssl support requires installing manually pyopenssl and cherrypy")
         root = os.getuid() == 0
         if root:
-            service_file = "/usr/lib/systemd/system/ksushy.service"
+            service_file = "/etc/systemd/system/ksushy.service"
         else:
             service_file = f"{os.environ.get('HOME')}/.config/systemd/user/ksushy.service"
         if not os.path.exists(os.path.dirname(service_file)):
