@@ -175,8 +175,7 @@ def scale(config, plandir, cluster, overrides):
     storedparameters = overrides.get('storedparameters', True)
     provider = config.type
     plan = cluster
-    data = {'cluster': cluster, 'kube': cluster, 'kubetype': 'hypershift', 'namespace': 'clusters', 'assisted': False,
-            'kubevirt': False}
+    data = {'cluster': cluster, 'kube': cluster, 'kubetype': 'hypershift', 'namespace': 'clusters'}
     data['basedir'] = '/workdir' if container_mode() else '.'
     cluster = data['cluster']
     namespace = data['namespace']
@@ -201,33 +200,64 @@ def scale(config, plandir, cluster, overrides):
         with open(f"{clusterdir}/ignition.sh", 'w') as f:
             f.write(ignitionscript)
         call(f'bash {clusterdir}/ignition.sh', shell=True)
+    old_assisted_vms_number = 2
     if storedparameters and os.path.exists(f"{clusterdir}/kcli_parameters.yml"):
         with open(f"{clusterdir}/kcli_parameters.yml", 'r') as install:
             installparam = safe_load(install)
             data.update(installparam)
             plan = installparam.get('plan', plan)
+            old_assisted_vms_number = installparam.get('assisted_vms_number', old_assisted_vms_number)
     data.update(overrides)
-    assisted = data['assisted']
-    kubevirt = data['kubevirt']
+    if os.path.exists(f"{clusterdir}/kubeconfig.mgmt"):
+        os.environ['KUBECONFIG'] = f"{clusterdir}/kubeconfig.mgmt"
+    if 'KUBECONFIG' not in os.environ:
+        warning("KUBECONFIG not set...Using .kube/config instead")
+    platform = data.get('platform')
+    assisted = platform == 'assisted'
+    assisted_vms = data.get('assisted_vms')
+    kubevirt = platform == 'kubevirt'
     with open(f"{clusterdir}/kcli_parameters.yml", 'w') as paramfile:
         safe_dump(data, paramfile, default_flow_style=False, encoding='utf-8', allow_unicode=True)
     pprint(f"Scaling on client {config.client}")
     worker_overrides = data.copy()
     workers = worker_overrides.get('workers', 2)
     if kubevirt:
-        # kubeconfig = data['kubeconfig']
-        # os.environ['KUBECONFIG'] = kubeconfig
         cmcmd = f"oc -n {namespace}-{cluster} scale nodepool {cluster} --replicas {workers}"
         call(cmcmd, shell=True)
         return {'result': 'success'}
     os.chdir(os.path.expanduser("~/.kcli"))
     old_baremetal_hosts = installparam.get('baremetal_hosts', [])
     new_baremetal_hosts = overrides.get('baremetal_hosts', [])
+    assisted_vms_number = overrides.get('workers') or data['assisted_vms_number']
+    if assisted_vms and assisted_vms_number != old_assisted_vms_number:
+        if assisted_vms_number < old_assisted_vms_number:
+            msg = "New assisted_vms_number should be greater than old one"
+            return {'result': 'failure', 'reason': msg}
+        if data.get('disk_size', 30) < 200:
+            data['disk_size'] = 200
+        if data.get('numcpus', 8) < 16:
+            data['numcpus'] = 16
+        if data.get('memory', 16384) < 20480:
+            data['memory'] = 20480
+        worker_threaded = data.get('threaded', False) or data.get('assisted_vms_threaded', False)
+        result = config.plan(plan, inputfile=f'{plandir}/kcli_plan_assisted.yml', overrides=data,
+                             threaded=worker_threaded)
+        if result['result'] != 'success':
+            return result
+        vms = result['newvms']
+        ksushy_ip = data['assisted_vms_ksushy_ip']
+        ksushy_url = f'http://{ksushy_ip}:9000/redfish/v1/Systems/{config.client}'
+        virtual_hosts = []
+        for vm in vms:
+            new_mac = config.k.info(vm)['nets'][0]['mac']
+            virtual_hosts.append({'url': f'{ksushy_url}/{vm}', 'mac': new_mac})
+        new_baremetal_hosts.extend(virtual_hosts)
     baremetal_hosts = [entry for entry in new_baremetal_hosts if entry not in old_baremetal_hosts]
     if baremetal_hosts:
         if assisted:
-            create_bmh_objects(config, plandir, cluster, namespace, baremetal_hosts, overrides)
-            cmcmd = f"oc -n {namespace}-{cluster} scale nodepool {cluster} --replicas {workers}"
+            all_baremetal_hosts = old_baremetal_hosts + baremetal_hosts
+            create_bmh_objects(config, plandir, cluster, namespace, all_baremetal_hosts, overrides)
+            cmcmd = f"oc -n {data['namespace']} scale nodepool {cluster} --replicas {len(all_baremetal_hosts)}"
             call(cmcmd, shell=True)
             return {'result': 'success'}
         else:
@@ -241,6 +271,8 @@ def scale(config, plandir, cluster, overrides):
                 iso_url = f'http://{svcip}:{svcport}/{cluster}-worker.iso'
             start_baremetal_hosts(baremetal_hosts, iso_url, overrides=overrides, debug=config.debug)
             worker_overrides['workers'] = workers - len(new_baremetal_hosts)
+    if platform is not None:
+        return {'result': 'success'}
     if worker_overrides.get('workers', 2) <= 0:
         return {'result': 'success'}
     threaded = data.get('threaded', False) or data.get('workers_threaded', False)
@@ -277,6 +309,7 @@ def create(config, plandir, cluster, overrides):
     ignore_hosts = data.get('ignore_hosts', False)
     pprint(f"Deploying cluster {clustervalue}")
     plan = cluster if cluster is not None else clustervalue
+    upstream = data['upstream']
     platform = data.get('platform')
     assisted = platform == 'assisted'
     data['assisted'] = assisted
@@ -321,7 +354,7 @@ def create(config, plandir, cluster, overrides):
     if which('oc') is None:
         get_oc()
     default_sc = False
-    for sc in safe_load(os.popen('oc get sc -o yaml').read())['items']:
+    for sc in safe_load(os.popen('oc get sc -o yaml').read()).get('items', []):
         if 'annotations' in sc['metadata']\
            and 'storageclass.kubernetes.io/is-default-class' in sc['metadata']['annotations']\
            and sc['metadata']['annotations']['storageclass.kubernetes.io/is-default-class'] == 'true':
@@ -341,17 +374,26 @@ def create(config, plandir, cluster, overrides):
     kubeconfig = os.path.basename(kubeconfig) if kubeconfig is not None else 'config'
     hosted_crd_cmd = 'oc get crd hostedclusters.hypershift.openshift.io -o yaml 2>/dev/null'
     assisted_crd_cmd = 'oc -n multicluster-engine get pod -l app=assisted-service -o name 2>/dev/null'
-    if safe_load(os.popen(hosted_crd_cmd).read()) is None\
-       or (assisted and safe_load(os.popen(assisted_crd_cmd).read()) is None):
-        warning("Hypershift not fully installed. Installing it for you")
-        if data['mce'] or assisted:
-            mce_assisted = assisted or data['mce_assisted']
-            app_name, source, channel, csv, description, x_namespace, channels, crds = olm_app('multicluster-engine')
-            app_data = {'name': app_name, 'source': source, 'channel': channel, 'namespace': x_namespace, 'csv': csv,
-                        'mce_hypershift': True, 'assisted': mce_assisted, 'version': version, 'tag': tag}
-            config.create_app_openshift(app_name, app_data)
-            sleep(240)
-        elif which('podman') is None:
+    need_hypershift = safe_load(os.popen(hosted_crd_cmd).read()) is None
+    need_assisted = assisted and safe_load(os.popen(assisted_crd_cmd).read()) is None
+    need_mce = (need_hypershift and not upstream) or need_assisted
+    if need_mce:
+        mce_hypershift = need_hypershift and not upstream
+        if mce_hypershift:
+            warning("Hypershift needed. Installing it for you")
+        if need_assisted:
+            warning("Also installing assisted")
+        app_name, source, channel, csv, description, x_namespace, channels, crds = olm_app('multicluster-engine')
+        app_data = {'name': app_name, 'source': source, 'channel': channel, 'namespace': x_namespace, 'csv': csv,
+                    'mce_hypershift': mce_hypershift, 'assisted': need_assisted, 'version': version, 'tag': tag}
+        config.create_app_openshift(app_name, app_data)
+        sleep(240)
+        if assisted and safe_load(os.popen(assisted_crd_cmd).read()) is None:
+            msg = "Couldnt install assisted via mce properly"
+            return {'result': 'failure', 'reason': msg}
+    if need_hypershift and upstream:
+        warning("Hypershift needed. Installing it for you")
+        if which('podman') is None:
             msg = "Please install podman first in order to install hypershift"
             return {'result': 'failure', 'reason': msg}
         else:
@@ -365,9 +407,6 @@ def create(config, plandir, cluster, overrides):
     if safe_load(os.popen(hosted_crd_cmd).read()) is None:
         msg = "Couldnt install hypershift properly"
         return {'result': 'failure', 'reason': msg}
-    elif assisted and safe_load(os.popen(assisted_crd_cmd).read()) is None:
-        msg = "Couldnt install assisted properly"
-        return {'result': 'failure', 'reason': msg}
     registry = 'quay.io'
     management_image = os.popen("oc get clusterversion version -o jsonpath='{.status.desired.image}'").read()
     prefixes = ['quay.io', 'registry.ci']
@@ -681,6 +720,12 @@ def create(config, plandir, cluster, overrides):
         assetsdata['nodepool_image'] = nodepool_image
     if assisted:
         if assisted_vms:
+            if data['disk_size'] < 200:
+                data['disk_size'] = 200
+            if data['numcpus'] < 16:
+                data['numcpus'] = 16
+            if data['memory'] < 20480:
+                data['memory'] = 20480
             worker_threaded = data.get('threaded', False) or data.get('assisted_vms_threaded', False)
             result = config.plan(plan, inputfile=f'{plandir}/kcli_plan_assisted.yml', overrides=data,
                                  threaded=worker_threaded)
@@ -694,11 +739,9 @@ def create(config, plandir, cluster, overrides):
                 new_mac = config.k.info(vm)['nets'][0]['mac']
                 virtual_hosts.append({'url': f'{ksushy_url}/{vm}', 'mac': new_mac})
             baremetal_hosts.extend(virtual_hosts)
+            data['assisted_vms_number'] = len(virtual_hosts)
         create_bmh_objects(config, plandir, cluster, namespace, baremetal_hosts, overrides)
-        agents = len(baremetal_hosts)
-        if not agents:
-            warning("No baremetal hosts were defined. Setting agent count to 2")
-            agents = 2
+        agents = len(baremetal_hosts) or 2
         pprint(f"Waiting for {agents} agents to appear")
         agent_ns = f"{namespace}-{cluster}"
         call(f'until [ "$(oc -n {agent_ns} get agent -o name | wc -l | xargs)" -eq "{agents}" ] ; do sleep 1 ; done',
@@ -752,6 +795,9 @@ def create(config, plandir, cluster, overrides):
             installparam['image'] = image
         installparam['ipv6'] = ipv6
         installparam['original_domain'] = data['original_domain']
+        if baremetal_hosts:
+            installparam['baremetal_hosts'] = baremetal_hosts
+        installparam['assisted_vms_number'] = data['assisted_vms_number']
         safe_dump(installparam, p, default_flow_style=False, encoding='utf-8', allow_unicode=True)
     nodepoolfile = config.process_inputfile(cluster, f"{plandir}/nodepool.yaml", overrides=assetsdata)
     with open(f"{clusterdir}/nodepool.yaml", 'w') as f:
