@@ -7,7 +7,8 @@ fi
 
 dnf -y install microshift {{ 'microshift-olm' if olm|default(False) else '' }} microshift-olm microshift-multus
 BASEDOMAIN={{ "$(hostname)" if sslip else cluster + '.' + domain }}
+IP=$(hostname -I | cut -d' ' -f1)
 
 microshift show-config > /etc/microshift/config.yaml
-python /root/scripts/config.py $BASEDOMAIN
+python /root/scripts/config.py $BASEDOMAIN $IP
 systemctl enable --now microshift
