@@ -1,8 +1,10 @@
 #!/usr/bin/env bash
-#
+
+export HOME=${HOME:-/root}
+
 oc create -f 99-metal3-provisioning.yaml >/dev/null 2>&1 || oc patch provisioning provisioning-configuration --type merge -p '{"spec":{"watchAllNamespaces": true}}'
 
-oc wait --for=condition=complete multiclusterhub/multiclusterhub --timeout=10m
+oc -n open-cluster-management wait --for=condition=complete multiclusterhub/multiclusterhub --timeout=10m
 
 until oc get crd/agentserviceconfigs.agent-install.openshift.io >/dev/null 2>&1 ; do sleep 1 ; done
 until oc get crd/clusterimagesets.hive.openshift.io >/dev/null 2>&1 ; do sleep 1 ; done
@@ -27,8 +29,8 @@ export RHCOS_ROOTFS=http://${BAREMETAL_IP}/rhcos-live-rootfs.x86_64.img
 
 export MINOR=$(openshift-install version | head -1 | cut -d' ' -f2 | cut -d. -f1,2)
 
-export PULLSECRET=$(cat {{ pull_secret|default('~/openshift_pull.json')|pwd_path }} | tr -d [:space:])
-export SSH_PRIV_KEY=$(cat {{ pub_key|default('~/.ssh/id_rsa') }} |sed "s/^/    /")
+export PULLSECRET=$(cat {{ pull_secret|default('$HOME/openshift_pull.json')|pwd_path }} | tr -d [:space:])
+export SSH_PRIV_KEY=$(cat {{ pub_key|default('$HOME/.ssh/id_rsa') }} |sed "s/^/    /")
 export VERSION=$(openshift-install coreos print-stream-json | jq -r '.["architectures"]["x86_64"]["artifacts"]["metal"]["release"]')
 export RELEASE=$(openshift-install version | grep 'release image' | cut -d' ' -f3)
 
