@@ -16,6 +16,6 @@ oc -n open-cluster-management patch ${DEPLOY_NAME} -p '{"spec":{"template":{"spe
 bash assisted-service.sh
 {% endif %}
 
-{% if acm_hypershift %}
-oc -n open-cluster-management patch multiclusterhub multiclusterhub --type=merge -p '{"spec":{"overrides":{"components":[{"name":"hypershift-preview","enabled": true}]}}}'
+{% if not acm_hypershift %}
+oc -n open-cluster-management patch multiclusterhub multiclusterhub --type=merge -p '{"spec":{"overrides":{"components":[{"name":"hypershift","enabled": false}]}}}'
 {% endif %}
