@@ -92,6 +92,9 @@ $ kcli create plan -f multi.yml -P ctlplanes=1 -P nodes=2 -P crio=true
 
 # Create a plan from a remote url, customizing some parameters
 $ kcli create plan -u https://github.com/karmab/kcli-plans/blob/main/kubernetes/kubernetes.yml -P ctlplanes=3
+
+# Run plan treating vm with installer in its name as a workflow
+$ kcli create plan -P installer_workflow=true
 """
 
 planinfo = """# Get info from a local plan file
@@ -144,6 +147,12 @@ $ kcli create vm -i centos9stream -P nets=['{"name": "default", "mtu": 1400}']
 $ img=centos9stream
 $ kcli create vm -i $img -P nets=['{"name":"default","ip":"192.168.122.250","netmask":"24","gateway":"192.168.122.1"}']
 
+# Create a vm with a dns entry
+$ kcli create vm -i centos9stream -P nets=['{"name":"default","reservedns":"true"}']
+
+# Create a vm with a dhcp reservation
+$ kcli create vm -i centos9stream -P nets=['{"name":"default","ip":"192.168.122.250","reserveip":"true"}']
+
 # Use more advanced information for disks
 $ kcli create vm -i centos9stream -P disks=['{"size": 10, "interface": "sata"}']
 
@@ -413,10 +422,10 @@ $ kcli download image -u http://super.qcow2 super
 """
 
 isodownload = """# Download debian iso
-$ kcli download iso -u https://cdimage.debian.org/debian-cd/current/amd64/iso-cd/debian-11.1.0-amd64-netinst.iso
+$ kcli download iso -P url=https://cdimage.debian.org/debian-cd/current/amd64/iso-cd/debian-11.1.0-amd64-netinst.iso
 
 # Download iso to specific pool
-$ kcli download iso -u http://super.iso -P pool=mypool
+$ kcli download iso -P url=http://super.iso -P pool=mypool
 """
 
 workflowcreate = """# Run workflow from a single script
@@ -438,7 +447,7 @@ $ kcli run workflow myscript.sh -P target=192.168.1.1
 $ kcli run workflow myworkflow -P cmds=[hostname]
 
 # Only output assets to dir without running
-$ kcli run workflow myscript.sh -do mydir
+$ kcli run workflow myscript.sh -o mydir
 
 """
 
