@@ -107,7 +107,8 @@ class Kubevirt(Kubecommon):
                metadata={}, securitygroups=[], vmuser=None):
         owners = []
         container_disk = overrides.get('container_disk', False)
-        guestagent = False
+        guest_agent = False
+        need_ssh_service = not tunnel and self.access_mode != 'External'
         if self.exists(name):
             return {'result': 'failure', 'reason': f"VM {name} already exists"}
         if image is not None:
@@ -208,10 +209,12 @@ class Kubevirt(Kubecommon):
             machine = overrides['machine']
             warning(f"Forcing machine type to {machine}")
         vm['spec']['template']['spec']['domain']['machine'] = {'type': machine}
-        if overrides.get('guest_memory', False):
+        if cpuhotplug:
+            vm['spec']['template']['spec']['domain']['cpu'] = {'cores': 1, 'sockets': int(numcpus), 'maxSockets': 64}
+        if memoryhotplug:
             del vm['spec']['template']['spec']['domain']['resources']['requests']
             del vm['spec']['template']['spec']['domain']['resources']['limits']
-            vm['spec']['template']['spec']['domain']['memory'] = {'guest': f'{memory}Mi'}
+            vm['spec']['template']['spec']['domain']['memory'] = {'guest': f'{memory}Mi', 'maxGuest': '102400Mi'}
         if cpumodel != 'host-model':
             vm['spec']['template']['spec']['domain']['cpu']['model'] = cpumodel
         if 'rng' in overrides and overrides['rng']:
@@ -311,7 +314,9 @@ class Kubevirt(Kubecommon):
                     return {'result': 'failure', 'reason': f"network {netname} not found"}
                 else:
                     newnet['multus'] = {'networkName': netname}
-                    guestagent = True
+                    guest_agent = True
+                    if index == 0:
+                        need_ssh_service = False
             else:
                 newnet['pod'] = {}
             interfaces.append(newif)
@@ -399,7 +404,7 @@ class Kubevirt(Kubecommon):
             vm['spec']['template']['spec']['domain']['devices']['disks'].append(newdisk)
             vm['spec']['template']['spec']['volumes'].append(myvolume)
             cloudinit = False
-        if guestagent:
+        if guest_agent:
             gcmds = []
             if image is not None and common.need_guest_agent(image):
                 gcmds.append('yum -y install qemu-guest-agent')
@@ -432,7 +437,7 @@ class Kubevirt(Kubecommon):
                                                                files=files, enableroot=enableroot,
                                                                overrides=overrides, storemetadata=storemetadata,
                                                                image=image, machine=machine, vmuser=vmuser)
-                if 'static' in metadata:
+                if 'static' in metadata and 'static' not in name:
                     warning("Legacy network not supported in kubevirt. Ignoring")
                     netdata = None
             embed_userdata = overrides.get('embed_userdata', self.embed_userdata)
@@ -530,7 +535,7 @@ class Kubevirt(Kubecommon):
                            'spec': {'selector': {'subdomain': newdomain}, 'clusterIP': 'None',
                                     'ports': [{'name': 'foo', 'port': 1234, 'targetPort': 1234}]}}
                 core.create_namespaced_service(namespace, dnsspec)
-        if not tunnel and self.access_mode != 'External':
+        if need_ssh_service:
             try:
                 core.read_namespaced_service(f'{name}-ssh', namespace)
             except:
@@ -784,8 +789,11 @@ class Kubevirt(Kubecommon):
         yamlinfo = {'name': name, 'nets': [], 'disks': [], 'status': state, 'creationdate': creationdate, 'host': host,
                     'namespace': namespace, 'id': uid}
         if 'cpu' in spectemplate['spec']['domain']:
-            numcpus = spectemplate['spec']['domain']['cpu']['cores']
-            yamlinfo['cpus'] = numcpus
+            cores = spectemplate['spec']['domain']['cpu'].get('cores', 1)
+            sockets = spectemplate['spec']['domain']['cpu'].get('sockets', 1)
+            threads = spectemplate['spec']['domain']['cpu'].get('threads', 1)
+            numcpus = cores * sockets * threads
+            yamlinfo['numcpus'] = numcpus
         memory = None
         if 'resources' in spectemplate['spec']['domain'] and 'requests' in spectemplate['spec']['domain']['resources']:
             memory = spectemplate['spec']['domain']['resources']['requests']['memory'].replace('M', '').replace('G', '')
@@ -991,11 +999,16 @@ class Kubevirt(Kubecommon):
             error(f"VM {name} not found")
             return {'result': 'failure', 'reason': f"VM {name} not found"}
         t = 'Template' if 'Template' in vm['spec'] else 'template'
-        vm['spec'][t]['spec']['domain']['resources']['requests']['memory'] = f"{memory}M"
-        vm['spec'][t]['spec']['domain']['resources']['limits']['memory'] = f"{memory}M"
-        crds.replace_namespaced_custom_object(DOMAIN, VERSION, namespace, "virtualmachines", name, vm)
-        warning("Change will only appear next full lifeclyclereboot")
-        return
+        domain = vm['spec'][t]['spec']['domain']
+        if 'memory' in domain and 'maxGuest' in domain['memory']:
+            vm['spec'][t]['spec']['domain']['memory']['guest'] = f"{memory}Mi"
+            crds.patch_namespaced_custom_object(DOMAIN, VERSION, namespace, "virtualmachines", name, vm)
+        else:
+            vm['spec'][t]['spec']['domain']['resources']['requests']['memory'] = f"{memory}M"
+            vm['spec'][t]['spec']['domain']['resources']['limits']['memory'] = f"{memory}M"
+            warning("Change will only appear next full lifeclyclereboot")
+            crds.replace_namespaced_custom_object(DOMAIN, VERSION, namespace, "virtualmachines", name, vm)
+        return {'result': 'success'}
 
     def update_cpus(self, name, numcpus):
         crds = self.crds
@@ -1006,10 +1019,15 @@ class Kubevirt(Kubecommon):
             error(f"VM {name} not found")
             return {'result': 'failure', 'reason': f"VM {name} not found"}
         t = 'Template' if 'Template' in vm['spec'] else 'template'
-        vm['spec'][t]['spec']['domain']['cpu']['cores'] = int(numcpus)
-        warning("Change will only appear next full lifeclyclereboot")
-        crds.replace_namespaced_custom_object(DOMAIN, VERSION, namespace, "virtualmachines", name, vm)
-        return
+        domain = vm['spec'][t]['spec']['domain']
+        if 'cpu' in domain and 'maxSockets' in domain['cpu']:
+            vm['spec'][t]['spec']['domain']['cpu']['sockets'] = numcpus
+            crds.patch_namespaced_custom_object(DOMAIN, VERSION, namespace, "virtualmachines", name, vm)
+        else:
+            vm['spec'][t]['spec']['domain']['cpu']['cores'] = int(numcpus)
+            warning("Change will only appear next full lifeclyclereboot")
+            crds.replace_namespaced_custom_object(DOMAIN, VERSION, namespace, "virtualmachines", name, vm)
+        return {'result': 'success'}
 
     def update_start(self, name, start=True):
         print("not implemented")
@@ -1345,10 +1363,10 @@ class Kubevirt(Kubecommon):
         crds = self.crds
         namespace = self.namespace
         apiversion = f"{MULTUSDOMAIN}/{MULTUSVERSION}"
-        vlanconfig = '"vlan": %s' % overrides['vlan'] if 'vlan' in overrides is not None else ''
-        bridge = 'bridge' in overrides and overrides['bridge']
-        ovs = 'ovs' in overrides and overrides['ovs']
-        ovn = 'ovn' in overrides and overrides['ovn']
+        vlanconfig = ', "vlan": %s' % overrides['vlan'] if 'vlan' in overrides is not None else ''
+        bridge = overrides.get('bridge', False)
+        ovs = overrides.get('ovs', False)
+        ovn = overrides.get('ovn', False)
         if 'type' in overrides:
             _type = overrides['type']
         elif ovs:
@@ -1363,12 +1381,12 @@ class Kubevirt(Kubecommon):
             if bridge:
                 ipam = '"isDefaultGateway": true, "forceAddress": false, "ipMasq": true, "hairpinMode": true'
                 ipam += ', "ipam": { "type": "host-local", "subnet": "%s" }' % cidr
-                config = '{ "type": "bridge", "bridge": "%s", %s }' % (name, ipam)
+                config = '{ "type": "bridge", "bridge": "%s", %s %s}' % (name, ipam, vlanconfig)
             else:
                 nad = overrides.get('nad', f"{namespace}/{name}")
                 layer = overrides.get('layer', "layer2" if not nat else "localnet")
                 config = f'"name": "{name}", "netAttachDefName": "{nad}", "subnets": "{cidr}", "topology": "{layer}"'
-                config = '{ "cniVersion": "0.3.1", "type": "ovn-k8s-cni-overlay", %s }' % config
+                config = '{ "cniVersion": "0.3.1", "type": "ovn-k8s-cni-overlay", %s %s}' % (config, vlanconfig)
                 if layer == 'localnet' and nat:
                     bridge = overrides.get('bridge', 'br-ex')
                     policy = {'apiVersion': 'nmstate.io/v1', 'kind': 'NodeNetworkConfigurationPolicy',
