@@ -185,7 +185,7 @@ class Ksphere:
             if imageobj is None:
                 return {'result': 'failure', 'reason': f"Image {image} not found"}
             datastores = self._datastores_datacenters()
-            if datastores[pool] != self.dc.name:
+            if os.path.basename(datastores[pool]) != self.dc.name:
                 return {'result': 'failure', 'reason': f"Pool {pool} doesn't belong to Datacenter {self.dc.name}"}
             if imagepool is None:
                 devices = imageobj.config.hardware.device
@@ -760,7 +760,7 @@ class Ksphere:
         guest = vm['guest']
         yamlinfo['name'] = name
         yamlinfo['id'] = summary.config.instanceUuid
-        yamlinfo['cpus'] = config.hardware.numCPU
+        yamlinfo['numcpus'] = config.hardware.numCPU
         yamlinfo['memory'] = config.hardware.memoryMB
         yamlinfo['status'] = translation[runtime.powerState]
         yamlinfo['nets'] = []
@@ -938,7 +938,8 @@ class Ksphere:
             devices = v.config.hardware.device
             for number, dev in enumerate(devices):
                 if type(dev).__name__ == 'vim.vm.device.VirtualDisk':
-                    results.append(f'{dev.backing.datastore.name}/{v.name}')
+                    prefix = '' if self.restricted else f'{dev.backing.datastore.name}/'
+                    results.append(f'{prefix}{v.name}')
         return sorted(results)
 
     def update_metadata(self, name, metatype, metavalue, append=False):
